Welcome to Hierarchical Matrices!
=================================

This package is the result of my master thesis at the `Institute of Mathematics, University of Zurich <http://www.math.uzh.ch/index.php?&L=1>`_

It provides an interface in python to the concept of hierarchical matrices as described by `W. Hackbusch <https://books.google.ch/books?id=LlNECwAAQBAJ>`_

The main goal is to provide an easy to use yet performing alternative to existing implementations in C

* Hosted on GitHub: `GitHub <https://github.com/maekke97/HierarchicalMatrices>`_
* Available on PyPi: `PyPi <https://pypi.python.org/pypi/HierMat>`_
* Documentation: `ReadTheDocs <http://hierarchicalmatrices.readthedocs.io/en/latest>`_
* Continuous Integration: `Travis CI <https://travis-ci.org/maekke97/HierarchicalMatrices>`_
* Code Coverage: `Coveralls <https://coveralls.io/github/maekke97/HierarchicalMatrices>`_
* Code Quality: `SonarQube <https://sonarqube.com/dashboard/index?id=hierarchicalmatrices>`_

.. image:: https://readthedocs.org/projects/hierarchicalmatrices/badge/

.. image:: https://travis-ci.org/maekke97/HierarchicalMatrices.svg?branch=master

.. image:: https://coveralls.io/repos/github/maekke97/HierarchicalMatrices/badge.svg?branch=master

.. image:: https://sonarqube.com/api/badges/gate?key=hierarchicalmatrices

.. image:: https://img.shields.io/pypi/v/HierMat.svg
   :target: https://pypi.python.org/pypi/HierMat